# SynapEvo
SynapEvo: Synaptic Evolution
 🙌An attempt to create a Evolutionary neural net library, will have all the numba optimizations for quicker processing!
 A copy of the darwinian theorems for creating better networks per generation.
 ---
 USAGE:

 Will update after I complete coding the thing!
